from pysparkutilities.spark_initializer import spark_initializer
from pysparkutilities import ds_initializer

import sys

if __name__ == '__main__':

    print('sys arguments {}'.format(sys.argv))

    # Input args preparation
    args = {}
    for _ in sys.argv[1:]:
        if "=" in _:
            p = _.split('=')
            args[p[0].replace("--", "", 1)] = p[1]

    # Spark initializer + create dataset
    spark = spark_initializer("PySpark-Utilities-Test", args)

    test = [("Finance",10),
            ("Marketing",20),
            ("Sales",30),
            ("IT",40)
            ]

    testColumns = ["dept_name", "dept_id"]
    testDf = spark.createDataFrame(data=test, schema=testColumns)
    testDf.printSchema()
    testDf.show(truncate=False)

    # Write the dataset
    ds_initializer.save_dataset(df=testDf)

    # Load the dataset
    data = ds_initializer.load_dataset(sc=spark, read_all=False)

    # Show dataset
    data.show(truncate=False)



from pyspark.sql import SparkSession
from pyspark.sql import HiveContext
from pyspark import SparkConf


def spark_initializer(app_name, args, additional_config=[]):

    input_datastorage_type = ""
    output_datastorage_type = ""

    if "dataStorageType-input-dataset" in args:
        input_datastorage_type = args["dataStorageType-input-dataset"].lower()

    if "dataStorageType-output-dataset" in args:
        output_datastorage_type = args["dataStorageType-output-dataset"].lower()

    if input_datastorage_type.startswith("hive"):

        config_tuples = [
            ('spark.sql.warehouse.dir', '/warehouse/tablespace/managed/hive'),
            ('hive.metastore.uris', args["hiveMetastoreUris-input-dataset"]),
            ('spark.hadoop.dfs.client.use.datanode.hostname', True),
            ('javax.jdo.option.ConnectionUserName', args["hiveUserName-input-dataset"]),
            ('javax.jdo.option.ConnectionPassword', args["hivePassword-input-dataset"]),
            ('hive.server2.enable.doAs', True),
            ('hive.metastore.client.connect.retry.delay', 5),
            ('hive.metastore.client.socket.timeout', 1800)
        ] + additional_config

        config = SparkConf().setAll(config_tuples)

        spark = SparkSession \
            .builder \
            .appName(app_name) \
            .config(conf=config) \
            .enableHiveSupport() \
            .getOrCreate()

    elif output_datastorage_type.startswith("hive"):

        config_tuples = [
            ('spark.sql.warehouse.dir', '/warehouse/tablespace/managed/hive'),
            ('hive.metastore.uris', args["hiveMetastoreUris-output-dataset"]),
            ('spark.hadoop.dfs.client.use.datanode.hostname', True),
            ('javax.jdo.option.ConnectionUserName', args["hiveUserName-output-dataset"]),
            ('javax.jdo.option.ConnectionPassword', args["hivePassword-output-dataset"]),
            ('hive.server2.enable.doAs', True),
            ('hive.metastore.client.connect.retry.delay', 5),
            ('hive.metastore.client.socket.timeout', 1800)
        ] + additional_config

        config = SparkConf().setAll(config_tuples)

        spark = SparkSession \
            .builder \
            .appName(app_name) \
            .config(conf=config) \
            .enableHiveSupport() \
            .getOrCreate()

        # Hive session
        hive = HiveContext(spark)
    else:

        if len(additional_config) is 0:

            spark = SparkSession.builder.appName(app_name).getOrCreate()

        else:

            config = SparkConf().setAll(additional_config)

            spark = SparkSession.builder.appName(app_name).config(conf=config).getOrCreate()

    return spark
